@@ -2,6 +2,7 @@
  * ark -- archiver for the KDE project
  *
  * Copyright (C) 2009 Harald Hvaal <haraldhv@stud.ntnu.no>
+ * Copyright (C) 2009-2011 Raphael Kubo da Costa <kubito@gmail.com>
  *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions
@@ -325,10 +326,13 @@ bool CliInterface::runProcess(const QString& programName, const QStringList& arg
         return false;
     }
 
-    Q_ASSERT(!m_process);
-
     kDebug() << "Executing" << programPath << arguments;
 
+    if (m_process) {
+        m_process->waitForFinished();
+        delete m_process;
+    }
+
 #ifdef Q_OS_WIN
     m_process = new KProcess();
 #else
@@ -364,7 +368,6 @@ bool CliInterface::runProcess(const QString& programName, const QStringList& arg
 
 void CliInterface::started()
 {
-    //m_state = 0;
     m_userCancelled = false;
 }
 
