@@ -23,111 +23,94 @@
 #include "kerfuffle/archive.h"
 #include "kerfuffle/jobs.h"
 
-#include <QList>
-#include <QPixmap>
-#include <QFont>
-#include <QMimeData>
-#include <QDir>
-#include <QtDBus/QtDBus>
-#include <QLatin1String>
-#include <QPersistentModelIndex>
-
 #include <KDebug>
+#include <KIconLoader>
 #include <KLocale>
 #include <KMimeType>
-#include <KIconLoader>
 #include <KIO/NetAccess>
 
+#include <QDir>
+#include <QFont>
+#include <QLatin1String>
+#include <QList>
+#include <QMimeData>
+#include <QPersistentModelIndex>
+#include <QPixmap>
+#include <QtDBus/QtDBus>
+
 using namespace Kerfuffle;
 
 class ArchiveDirNode;
 
 //used to speed up the loading of large archives
-static ArchiveNode* previousMatch = NULL;
-static QStringList previousPieces;
-static int currentSortColumn = 0;
+static ArchiveNode* s_previousMatch = NULL;
+K_GLOBAL_STATIC(QStringList, s_previousPieces)
 
 
+// TODO: This class hierarchy needs some love.
+//       Having a parent take a child class as a parameter in the constructor
+//       should trigger one's spider-sense (TM).
 class ArchiveNode
 {
 public:
     ArchiveNode(ArchiveDirNode *parent, const ArchiveEntry & entry)
-            : m_parent(parent) {
+        : m_parent(parent)
+    {
         setEntry(entry);
     }
 
-    virtual ~ArchiveNode() {}
-
-    static bool compareAscending(const QPair<ArchiveNode*,int> &a, const QPair<ArchiveNode*,int> &b) {
-        // #234373: sort folders before files
-        if ((a.first->isDir()) && (!b.first->isDir())) {
-            return true;
-        } else if ((!a.first->isDir()) && (b.first->isDir())) {
-            return false;
-        }
-
-        if (currentSortColumn == FileName) {
-            return (a.first->m_name < b.first->m_name);
-        } else if ((currentSortColumn == Size) ||
-                   (currentSortColumn == CompressedSize)) {
-            return (a.first->entry()[currentSortColumn].toInt() < b.first->entry()[currentSortColumn].toInt());
-        } else {
-            return (a.first->entry()[currentSortColumn].toString() < b.first->entry()[currentSortColumn].toString());
-        }
+    virtual ~ArchiveNode()
+    {
     }
 
-    static bool compareDescending(const QPair<ArchiveNode*,int> &a, const QPair<ArchiveNode*,int> &b) {
-        // #234373: sort folders before files
-        if ((a.first->isDir()) && (!b.first->isDir())) {
-            return true;
-        } else if ((!a.first->isDir()) && (b.first->isDir())) {
-            return false;
-        }
-
-        if (currentSortColumn == FileName) {
-            return (a.first->m_name > b.first->m_name);
-        } else if ((currentSortColumn == Size) ||
-                   (currentSortColumn == CompressedSize)) {
-            return (a.first->entry()[currentSortColumn].toInt() > b.first->entry()[currentSortColumn].toInt());
-        } else {
-            return (a.first->entry()[currentSortColumn].toString() > b.first->entry()[currentSortColumn].toString());
-        }
-    }
-
-    const ArchiveEntry &entry() const {
+    const ArchiveEntry &entry() const
+    {
         return m_entry;
     }
-    void setEntry(const ArchiveEntry& entry) {
+
+    void setEntry(const ArchiveEntry& entry)
+    {
         m_entry = entry;
 
         const QStringList pieces = entry[FileName].toString().split(QLatin1Char( '/' ), QString::SkipEmptyParts);
         m_name = pieces.isEmpty() ? QString() : pieces.last();
+
+        const KMimeType::Ptr mimeType = KMimeType::findByPath(m_entry[FileName].toString(), 0, true);
+        m_icon = KIconLoader::global()->loadMimeTypeIcon(mimeType->iconName(), KIconLoader::Small);
     }
 
-    ArchiveDirNode *parent() const {
+    ArchiveDirNode *parent() const
+    {
         return m_parent;
     }
 
-    int row();
+    int row() const;
 
-    virtual bool isDir() const {
+    virtual bool isDir() const
+    {
         return false;
     }
 
-    QPixmap icon() {
-        if (m_icon.isNull()) {
-            KMimeType::Ptr mimeType = KMimeType::findByPath(m_entry[ FileName ].toString(), 0, true);
-            m_icon = KIconLoader::global()->loadMimeTypeIcon(mimeType->iconName(), KIconLoader::Small);
-        }
+    QPixmap icon() const
+    {
         return m_icon;
     }
-    QString         m_name;
+
+    QString name() const
+    {
+        return m_name;
+    }
 
 protected:
-    QPixmap         m_icon;
+    void setIcon(const QPixmap &icon)
+    {
+        m_icon = icon;
+    }
 
 private:
     ArchiveEntry    m_entry;
+    QPixmap         m_icon;
+    QString         m_name;
     ArchiveDirNode *m_parent;
 };
 
@@ -136,34 +119,40 @@ class ArchiveDirNode: public ArchiveNode
 {
 public:
     ArchiveDirNode(ArchiveDirNode *parent, const ArchiveEntry & entry)
-            : ArchiveNode(parent, entry) {
-        m_icon = KIconLoader::global()->loadMimeTypeIcon(KMimeType::mimeType(QLatin1String( "inode/directory" ))->iconName(), KIconLoader::Small);
+        : ArchiveNode(parent, entry)
+    {
     }
 
-
-    ~ArchiveDirNode() {
+    ~ArchiveDirNode()
+    {
         clear();
     }
 
-    QList<ArchiveNode*>& entries() {
+    // TODO: Do not return a reference, add methods to change m_entries.
+    //       Returning a reference makes the code less readable, as m_entries,
+    //       which is private, ends up being changed all over this file.
+    QList<ArchiveNode*>& entries()
+    {
         return m_entries;
     }
 
-    virtual bool isDir() const {
+    virtual bool isDir() const
+    {
         return true;
     }
 
-    ArchiveNode* find(const QString & name) {
+    ArchiveNode* find(const QString & name)
+    {
         foreach(ArchiveNode *node, m_entries) {
-            if (node && (node->m_name == name)) {
+            if (node && (node->name() == name)) {
                 return node;
             }
         }
         return 0;
     }
 
-    ArchiveNode* findByPath(const QStringList & pieces, int index = 0) {
-
+    ArchiveNode* findByPath(const QStringList & pieces, int index = 0)
+    {
         if (index == pieces.count()) {
             return 0;
         }
@@ -179,7 +168,8 @@ public:
         return 0;
     }
 
-    void returnDirNodes(QList<ArchiveDirNode*> *store) {
+    void returnDirNodes(QList<ArchiveDirNode*> *store)
+    {
         foreach(ArchiveNode *node, m_entries) {
             if (node->isDir()) {
                 store->prepend(static_cast<ArchiveDirNode*>(node));
@@ -188,7 +178,8 @@ public:
         }
     }
 
-    void clear() {
+    void clear()
+    {
         qDeleteAll(m_entries);
         m_entries.clear();
     }
@@ -197,7 +188,72 @@ private:
     QList<ArchiveNode*> m_entries;
 };
 
-int ArchiveNode::row()
+/**
+ * Helper functor used by qStableSort.
+ *
+ * It always sorts folders before files.
+ *
+ * @internal
+ */
+class ArchiveModelSorter
+{
+public:
+    ArchiveModelSorter(int column, Qt::SortOrder order)
+        : m_sortColumn(column)
+        , m_sortOrder(order)
+    {
+    }
+
+    virtual ~ArchiveModelSorter()
+    {
+    }
+
+    inline bool operator()(const QPair<ArchiveNode*, int> &left, const QPair<ArchiveNode*, int> &right) const
+    {
+        if (m_sortOrder == Qt::AscendingOrder) {
+            return lessThan(left, right);
+        } else {
+            return !lessThan(left, right);
+        }
+    }
+
+protected:
+    bool lessThan(const QPair<ArchiveNode*, int> &left, const QPair<ArchiveNode*, int> &right) const
+    {
+        const ArchiveNode * const leftNode = left.first;
+        const ArchiveNode * const rightNode = right.first;
+
+        // #234373: sort folders before files
+        if ((leftNode->isDir()) && (!rightNode->isDir())) {
+            return (m_sortOrder == Qt::AscendingOrder);
+        } else if ((!leftNode->isDir()) && (rightNode->isDir())) {
+            return !(m_sortOrder == Qt::AscendingOrder);
+        }
+
+        const QVariant &leftEntry = leftNode->entry()[m_sortColumn];
+        const QVariant &rightEntry = rightNode->entry()[m_sortColumn];
+
+        switch (m_sortColumn) {
+        case FileName:
+            return leftNode->name() < rightNode->name();
+        case Size:
+        case CompressedSize:
+            return leftEntry.toInt() < rightEntry.toInt();
+        default:
+            return leftEntry.toString() < rightEntry.toString();
+        }
+
+        // We should not get here.
+        Q_ASSERT(false);
+        return false;
+    }
+
+private:
+    int m_sortColumn;
+    Qt::SortOrder m_sortOrder;
+};
+
+int ArchiveNode::row() const
 {
     if (parent()) {
         return parent()->entries().indexOf(const_cast<ArchiveNode*>(this));
@@ -230,9 +286,14 @@ QVariant ArchiveModel::data(const QModelIndex &index, int role) const
             int columnId = m_showColumns.at(index.column());
             switch (columnId) {
             case FileName:
-                return node->m_name;
+                return node->name();
             case Size:
-                if (node->isDir() || node->entry().contains(Link)) {
+                if (node->isDir()) {
+                    int dirs;
+                    int files;
+                    const int children = childCount(index, dirs, files);
+                    return KIO::itemsSummaryString(children, files, dirs, 0, false);
+                } else if (node->entry().contains(Link)) {
                     return QVariant();
                 } else {
                     return KIO::convertSize(node->entry()[ Size ].toULongLong());
@@ -258,7 +319,7 @@ QVariant ArchiveModel::data(const QModelIndex &index, int role) const
                         return QVariant();
                     } else {
                         int ratio = int(100 * ((double)size - compressedSize) / size);
-                        return QString::number(ratio) + QLatin1String( " %" );
+                        return QString(QString::number(ratio) + QLatin1String( " %" ));
                     }
                 }
 
@@ -383,13 +444,22 @@ ArchiveEntry ArchiveModel::entryForIndex(const QModelIndex &index)
     return ArchiveEntry();
 }
 
-int ArchiveModel::childCount(const QModelIndex &index)
+int ArchiveModel::childCount(const QModelIndex &index, int &dirs, int &files) const
 {
     if (index.isValid()) {
+        dirs = files = 0;
         ArchiveNode *item = static_cast<ArchiveNode*>(index.internalPointer());
         Q_ASSERT(item);
         if (item->isDir()) {
-            return static_cast<ArchiveDirNode*>(item)->entries().count();
+            const QList<ArchiveNode*> entries = static_cast<ArchiveDirNode*>(item)->entries();
+            foreach(const ArchiveNode *node, entries) {
+                if (node->isDir()) {
+                    dirs++;
+                } else {
+                    files++;
+                }
+            }
+            return entries.count();
         }
         return 0;
     }
@@ -422,14 +492,14 @@ void ArchiveModel::sort(int column, Qt::SortOrder order)
         return;
     }
 
-    currentSortColumn = m_showColumns.at(column);
-
     emit layoutAboutToBeChanged();
 
     QList<ArchiveDirNode*> dirNodes;
     m_rootNode->returnDirNodes(&dirNodes);
     dirNodes.append(m_rootNode);
 
+    const ArchiveModelSorter modelSorter(m_showColumns.at(column), order);
+
     foreach(ArchiveDirNode* dir, dirNodes) {
         QVector < QPair<ArchiveNode*,int> > sorting(dir->entries().count());
         for (int i = 0; i < dir->entries().count(); ++i) {
@@ -438,11 +508,7 @@ void ArchiveModel::sort(int column, Qt::SortOrder order)
             sorting[i].second = i;
         }
 
-        if (order == Qt::AscendingOrder) {
-            qStableSort(sorting.begin(), sorting.end(), ArchiveNode::compareAscending);
-        } else {
-            qStableSort(sorting.begin(), sorting.end(), ArchiveNode::compareDescending);
-        }
+        qStableSort(sorting.begin(), sorting.end(), modelSorter);
 
         QModelIndexList fromIndexes;
         QModelIndexList toIndexes;
@@ -571,15 +637,15 @@ ArchiveDirNode* ArchiveModel::parentFor(const ArchiveEntry& entry)
     }
     pieces.removeLast();
 
-    if (previousMatch) {
+    if (s_previousMatch) {
         //the number of path elements must be the same for the shortcut
         //to work
-        if (previousPieces.count() == pieces.count()) {
+        if (s_previousPieces->count() == pieces.count()) {
             bool equal = true;
 
             //make sure all the pieces match up
-            for (int i = 0; i < previousPieces.count(); ++i) {
-                if (previousPieces.at(i) != pieces.at(i)) {
+            for (int i = 0; i < s_previousPieces->count(); ++i) {
+                if (s_previousPieces->at(i) != pieces.at(i)) {
                     equal = false;
                     break;
                 }
@@ -587,7 +653,7 @@ ArchiveDirNode* ArchiveModel::parentFor(const ArchiveEntry& entry)
 
             //if match return it
             if (equal) {
-                return static_cast<ArchiveDirNode*>(previousMatch);
+                return static_cast<ArchiveDirNode*>(s_previousMatch);
             }
         }
     }
@@ -614,8 +680,8 @@ ArchiveDirNode* ArchiveModel::parentFor(const ArchiveEntry& entry)
         parent = static_cast<ArchiveDirNode*>(node);
     }
 
-    previousMatch = parent;
-    previousPieces = pieces;
+    s_previousMatch = parent;
+    *s_previousPieces = pieces;
 
     return parent;
 }
@@ -797,8 +863,8 @@ KJob* ArchiveModel::setArchive(Kerfuffle::Archive *archive)
     delete m_archive;
     m_archive = archive;
     m_rootNode->clear();
-    previousMatch = 0;
-    previousPieces = QStringList();
+    s_previousMatch = 0;
+    s_previousPieces->clear();
 
 
     Kerfuffle::ListJob *job = NULL;
