@@ -22,8 +22,8 @@
 
 */
 
-#ifndef _KCALC_CORE_H
-#define _KCALC_CORE_H
+#ifndef KCALC_CORE_H_
+#define KCALC_CORE_H_
 
 #include <QStack>
 #include "stats.h"
@@ -36,10 +36,6 @@
 typedef KNumber(*Arith)(const KNumber &, const KNumber &);
 typedef KNumber(*Prcnt)(const KNumber &, const KNumber &);
 
-#define UNUSED(x) ((void)(x))
-
-
-
 struct operator_data {
     int precedence;  // priority of operators in " enum Operation"
     Arith arith_ptr;
@@ -77,54 +73,54 @@ public:
     void enterOperation(KNumber num, Operation func);
 
 
-    void ArcCosDeg(KNumber input);
-    void ArcCosRad(KNumber input);
-    void ArcCosGrad(KNumber input);
-    void ArcSinDeg(KNumber input);
-    void ArcSinRad(KNumber input);
-    void ArcSinGrad(KNumber input);
-    void ArcTangensDeg(KNumber input);
-    void ArcTangensRad(KNumber input);
-    void ArcTangensGrad(KNumber input);
-    void AreaCosHyp(KNumber input);
-    void AreaSinHyp(KNumber input);
-    void AreaTangensHyp(KNumber input);
-    void Complement(KNumber input);
-    void CosDeg(KNumber input);
-    void CosRad(KNumber input);
-    void CosGrad(KNumber input);
-    void CosHyp(KNumber input);
-    void Cube(KNumber input);
-    void CubeRoot(KNumber input);
-    void Exp(KNumber input);
-    void Exp10(KNumber input);
-    void Factorial(KNumber input);
-    void InvertSign(KNumber input);
-    void Ln(KNumber input);
-    void Log10(KNumber input);
+    void ArcCosDeg(const KNumber &input);
+    void ArcCosRad(const KNumber &input);
+    void ArcCosGrad(const KNumber &input);
+    void ArcSinDeg(const KNumber &input);
+    void ArcSinRad(const KNumber &input);
+    void ArcSinGrad(const KNumber &input);
+    void ArcTangensDeg(const KNumber &input);
+    void ArcTangensRad(const KNumber &input);
+    void ArcTangensGrad(const KNumber &input);
+    void AreaCosHyp(const KNumber &input);
+    void AreaSinHyp(const KNumber &input);
+    void AreaTangensHyp(const KNumber &input);
+    void Complement(const KNumber &input);
+    void CosDeg(const KNumber &input);
+    void CosRad(const KNumber &input);
+    void CosGrad(const KNumber &input);
+    void CosHyp(const KNumber &input);
+    void Cube(const KNumber &input);
+    void CubeRoot(const KNumber &input);
+    void Exp(const KNumber &input);
+    void Exp10(const KNumber &input);
+    void Factorial(const KNumber &input);
+    void InvertSign(const KNumber &input);
+    void Ln(const KNumber &input);
+    void Log10(const KNumber &input);
     void ParenClose(KNumber input);
-    void ParenOpen(KNumber input);
-    void Reciprocal(KNumber input);
-    void SinDeg(KNumber input);
-    void SinGrad(KNumber input);
-    void SinRad(KNumber input);
-    void SinHyp(KNumber input);
-    void Square(KNumber input);
-    void SquareRoot(KNumber input);
-    void StatClearAll(KNumber input);
-    void StatCount(KNumber input);
-    void StatDataNew(KNumber input);
-    void StatDataDel(KNumber input);
-    void StatMean(KNumber input);
-    void StatMedian(KNumber input);
-    void StatStdDeviation(KNumber input);
-    void StatStdSample(KNumber input);
-    void StatSum(KNumber input);
-    void StatSumSquares(KNumber input);
-    void TangensDeg(KNumber input);
-    void TangensRad(KNumber input);
-    void TangensGrad(KNumber input);
-    void TangensHyp(KNumber input);
+    void ParenOpen(const KNumber &input);
+    void Reciprocal(const KNumber &input);
+    void SinDeg(const KNumber &input);
+    void SinGrad(const KNumber &input);
+    void SinRad(const KNumber &input);
+    void SinHyp(const KNumber &input);
+    void Square(const KNumber &input);
+    void SquareRoot(const KNumber &input);
+    void StatClearAll(const KNumber &input);
+    void StatCount(const KNumber &input);
+    void StatDataNew(const KNumber &input);
+    void StatDataDel(const KNumber &input);
+    void StatMean(const KNumber &input);
+    void StatMedian(const KNumber &input);
+    void StatStdDeviation(const KNumber &input);
+    void StatStdSample(const KNumber &input);
+    void StatSum(const KNumber &input);
+    void StatSumSquares(const KNumber &input);
+    void TangensDeg(const KNumber &input);
+    void TangensRad(const KNumber &input);
+    void TangensGrad(const KNumber &input);
+    void TangensHyp(const KNumber &input);
 
     void Reset();
 private:
@@ -133,7 +129,7 @@ private:
     typedef struct {
         KNumber number;
         Operation operation;
-    } _node;
+    } Node;
 
     // Stack holds all operations and numbers that have not yet been
     // processed, e.g. user types "2+3*", the calculation can not be
@@ -154,33 +150,33 @@ private:
     // into the stack, each time the user opens one.  When a bracket is
     // closed, everything in the stack is evaluated until the first
     // marker "FUNC_BRACKET" found.
-    QStack<_node> _stack;
+    QStack<Node> stack_;
 
-    KNumber _last_number;
+    KNumber last_number_;
 
-    bool _percent_mode;
+    bool percent_mode_;
 
 
     static const struct operator_data Operator[];
 
-    bool evalStack(void);
+    bool evalStack();
 
-    KNumber evalOperation(KNumber arg1, Operation operation, KNumber arg2);
+    KNumber evalOperation(const KNumber &arg1, Operation operation, const KNumber &arg2);
 
-    const KNumber Deg2Rad(const KNumber &x) const {
+    KNumber Deg2Rad(const KNumber &x) const {
         return KNumber(2) * KNumber::Pi() / KNumber(360) * x;
     }
-    const KNumber Gra2Rad(const KNumber &x) const {
+    KNumber Gra2Rad(const KNumber &x) const {
         return KNumber(2)*KNumber::Pi() / KNumber(400) * x;
     }
-    const KNumber Rad2Deg(const KNumber &x) const {
+    KNumber Rad2Deg(const KNumber &x) const {
         return KNumber(360) / (KNumber(2) * KNumber::Pi()) * x;
     }
-    const KNumber Rad2Gra(const KNumber &x) const {
+    KNumber Rad2Gra(const KNumber &x) const {
         return KNumber(400) / (KNumber(2)*KNumber::Pi()) * x;
     }
 
 };
 
 
-#endif  //_KCALC_CORE_H
+#endif  // KCALC_CORE_H_
