@@ -30,6 +30,7 @@ class KGpgDecrypt: public KGpgTextOrFileTransaction {
 	Q_OBJECT
 
 	Q_DISABLE_COPY(KGpgDecrypt)
+	KGpgDecrypt(); // = delete C++0x
 public:
 	/**
 	 * @brief decrypt given text
@@ -70,6 +71,7 @@ protected:
 
 private:
 	int m_fileIndex;
+	int m_plainLength;	///< length of decrypted plain text if given by GnuPG
 };
 
 #endif // KGPGDECRYPT_H
